@@ -72,10 +72,7 @@ def loads_indicators(csvdata):
             if not pdtypes.is_numeric_dtype(dataframe[col]):
                 dataframe[col] = dataframe[col].map(__load_json)
         except:
-            traceback.print_exc()
-            print('json.loads failed')
-        else:
-            print('json.loads succeed')
+            pass
     dataframe.replace(-1, np.NaN, inplace=True)
     dataframe.replace('-1', np.NaN, inplace=True)
     try:
